.. _tables_io:


API Documentation for tables_io
*******************************

Stuff


TableDict interface
===================

`tables_io.TableDict`
---------------------

.. automodule:: tables_io.tableDict
    :members:
    :undoc-members:


Tables types and File Formats
=============================

`tables_io.types`
-----------------

.. automodule:: tables_io.types
    :members:
    :undoc-members:


      
Infrastructure and Core functionality
=====================================

`tables_io.arrayUtils`
----------------------

.. automodule:: tables_io.arrayUtils
    :members:
    :undoc-members:


`tables_io.convUtils`
---------------------

.. automodule:: tables_io.convUtils
    :members:
    :undoc-members:


`tables_io.ioUtils`
-------------------

.. automodule:: tables_io.ioUtils
    :members:
    :undoc-members:


`tables_io.testUtils`
---------------------

.. automodule:: tables_io.testUtils
    :members:
    :undoc-members:
